@@ -71,7 +71,10 @@ def get_semantic_predictability(word_sense,context_senses,debug=False,style='A')
             continue
         score += relatedness(word_sense,s)
     if style == 'A':
-        score = float(score)/float(len(context_senses))
+        try:
+            score = float(score)/float(len(context_senses))
+        except ZeroDivisionError:
+            pass
     return score
 
 def to_wordnet_sense(sense_string):
